@@ -26,7 +26,7 @@ DEFAULT_EXPERIMENT_LOG_LEVEL = 'DEBUG'
 class PPlusConnection(object):
 
     def __init__(self, id=None, config_file_path=None, debug=True,
-                 local_workers_number=None, workers_servers=None, secret=None):
+                 local_workers_number=None, workers_servers=None, secret=None, experiment_label=None):
         """Implements common end point for accessing PPlus environment.
 
         Parameters
@@ -35,6 +35,10 @@ class PPlusConnection(object):
             experiment id. if None, create master connection instance;
             otherwise, create worker connection instance.
 
+            Experiment ID is currently generated as :func:`uuid.uuid1` (for master
+            connection) and :func:`uuid.uuid4` (for worker connection). See also
+            "experiment_label" option.
+
         config_file_path : str, optional (default: None)
             path to PPlus configuration file.
 
@@ -55,8 +59,8 @@ class PPlusConnection(object):
             In normal mode, None means 0.
 
         workers_servers : list, optional (default: None)
-            list of pplus servers addresses. Is possible to specify port
-            numbers using the format 'address:port'.
+            list of pplus servers addresses. It is possible to specify also port
+            by using the format 'address:port'.
             Default port number is 60000
             If None, servers are automatically discovered (if they are running
             in auto-discovery mode).
@@ -68,6 +72,14 @@ class PPlusConnection(object):
 
             **In debug mode this option is ignored.**
 
+        experiment_label : str, optional (default: None)
+            label assigned to experiment
+
+            If not None, the label will be prepended to experiment id, and
+            experiment will be identified as '<label>_<id>'. This may ease the
+            identification of particular experiment among others, since id is
+            unique but not human readable. See "id" option notes for more details.
+
         Raises
         ------
         PPlusError
@@ -140,9 +152,16 @@ class PPlusConnection(object):
         self._local_workers = local_workers_number
 
         ### Experiment and Session id creations
+        ### Matteo 2013-02-28 The experiment ID is either
+        ### 1) a string passed as an argument (in workers)
+        ### 2) created appending an unique generated hash to a given experiment_label
+        ### 3) a string generated by the uuid1() function
         if id:
             self._id = str(id)
             session_type = 'worker'
+        elif experiment_label:
+            self._id = experiment_label + "_" + str(uuid.uuid1().hex)
+            session_type = 'master'
         else:
             self._id = uuid.uuid1().hex
             session_type = 'master'
@@ -429,14 +448,26 @@ class PPlusConnection(object):
 
     ### Public Methods: Jobs managing  ----------------------------------------
     def submit(self, function, args=(), depfuncs=(), modules=()):
-        """Submit requested callable as a task to be executed in parallel
+        """Submit requested callable/deepfunction as a task to be executed in parallel
         within current PPlus environment.
 
-        The callable **have to accept** as first parameter an instance
+        The callable **has to accept** as first parameter an instance
         of :class:`PPlusConnection` which will be instantiated and
         passed automatically by PPlus and may return any valid Python
         pickeable object.
 
+        .. note::
+
+            For `direct` submission, "function" is a callable. However, callable
+            can be also submitted in `indirect` mode, where callable itself is
+            added to `depfuncs` and callable name is given as "function". During
+            job execution, callable is then reconstructed in correct scope by
+            its name. This mechanism allows circumventing natural limitations
+            of callable submission in Parallel Python (which stems from limitations
+            of function pickling in Python itself), and allows submission of `any`
+            function, if only accessible through :data:`sys.path`. See :ref:`submission`
+            for more details.
+
         .. warning::
 
             If your job function produce a very big result may be more
@@ -461,8 +492,12 @@ class PPlusConnection(object):
 
         Parameters
         ----------
-        function : callable
-            callable to be sent as task for parallel execution.
+        function : callable/string
+            callable object/callable name to be sent as task for parallel execution.
+
+            If string, "function" is interpreted as callable `name`. Subsequently,
+            the corresponding callable MUST be added to `depfuncs`, otherwise an
+            error will occur!
 
         args : iterable
             any positional arguments for requested callable.
