@@ -437,8 +437,13 @@ class Server(object):
         self.__queue.append((task, sfunc, sargs))
         self.__queue_lock.release()
 
+        try:
+            tname = args[0].func_name
+        except:
+            tname = args[0]
+
         self.logger.debug("Task %i submitted, function='%s'" %
-                          (tid, args[0].func_name))
+                          (tid, tname))
         self.__scheduler()
         return task
 
